==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPKeepAliveMsg.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const TRIPKeepAliveMsg_cxx_Version = 
"$Id: TRIPKeepAliveMsg.cxx,v 1.1 2000/10/26 19:51:08 surendra Exp $";

#include "TRIPKeepAliveMsg.hxx"
#include "cpLog.h"

TRIPKeepAliveMsg::TRIPKeepAliveMsg()
    :TRIPMsg()
{
    _hdr = new TRIPHeader(TRIP_OP_KEEPALIVE, 3);
}

void 
TRIPKeepAliveMsg::dump(ostream& os)const
{
   os.width(25);
   os << "**KeepAliveMsg**" << endl;
   os << *_hdr << endl; 
}

void 
TRIPKeepAliveMsg::parse(const TRIPHeader& hdr,
                          const char* data) throw (TRIPBadDataException&)
{
    if(!(hdr.isAKeepAliveHdr() && (hdr.getMsgLength() == 3)))
    {
        cpLog(LOG_ALERT, "Bad KeepAlive Msg");
        throw TRIPBadDataException("Bad KeepAlive Msg", __FILE__, __LINE__, 0);
    }
}

void 
TRIPKeepAliveMsg::parse(const char* data) throw (TRIPBadDataException&) 
{
    parseHeader(data);
}


void 
TRIPKeepAliveMsg::writeData(int id) const throw(VNetworkException&)
{
    TRIPMsg::writeData(id);
}

void 
TRIPKeepAliveMsg::checkSanity() const throw (TRIPBadDataException&)
{
    if(!(_hdr->isAKeepAliveHdr() && (_hdr->getMsgLength() == 3)))
    {
        cpLog(LOG_ALERT, "Bad KeepAlive Msg");
        throw TRIPBadDataException("Bad KeepAlive Msg", __FILE__, __LINE__, 0);
    }
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPKeepAliveMsg.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const TRIPKeepAliveMsg_cxx_Version = 
"$Id: TRIPKeepAliveMsg.cxx,v 1.4 2001/03/05 20:21:19 kevinmc Exp $";

#include "TRIPKeepAliveMsg.hxx"
#include "TRIPErrorHandler.hxx"
#include "cpLog.h"

#define DUMP_LABEL_WIDTH 25

TRIPKeepAliveMsg::TRIPKeepAliveMsg()
    :TRIPMsg()
{
    _hdr = new TRIPHeader(TRIP_OP_KEEPALIVE);
}

void 
TRIPKeepAliveMsg::dump(ostream& os)const
{
   os.width(DUMP_LABEL_WIDTH);
   os << "**KeepAliveMsg**" << endl;
   os << *_hdr << endl; 
}

void 
TRIPKeepAliveMsg::parse(const TRIPHeader& hdr,
                          const char* data) throw (TRIPBadDataException&)
{
    checkSanity();
}

void 
TRIPKeepAliveMsg::parse(const char* data) throw (TRIPBadDataException&) 
{
    assert(data);
    parseHeader(data);
    checkSanity();
}

void 
TRIPKeepAliveMsg::checkSanity() const throw (TRIPBadDataException&)
{
    if(!(_hdr->isAKeepAliveHdr() && (_hdr->getMsgLength() == _hdr->getHdrLength())))
    {
        throw TRIPBadDataException("Bad KeepAlive Msg", __FILE__, __LINE__, 
                                TRIP_ERR_MSG_HEADER, H_BAD_MSG_LENGTH);
    }
}
